import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:dio/dio.dart';

class _MyAppEndpoint {
  _MyAppEndpoint._();
  static String getLegalContent() => "v2/legal/getLegalContent";
  static String acceptTerms() => "v2/legal/acceptTerms"; 
}

abstract class MyAppApi {
  Future<NetworkResponse> getLegalContent(params);
  Future<NetworkResponse> acceptTerms(params);
}

class MyAppApiImp extends MyAppApi {
  @override
  Future<NetworkResponse> getLegalContent(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(requiredToken: false)
          .get(_MyAppEndpoint.getLegalContent(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => LegalInfo.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> acceptTerms(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(_MyAppEndpoint.acceptTerms(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }
}
