enum LocationType { home, work, other }

class LocationModel {
  int? id;
  String? uniqueId;
  late String locationLabel;
  late int favourite;
  late String street;
  String? zip;
  late String city;
  late String state;
  late String country;
  String? utcModifier;
  late double lat;
  late double lng;
  late LocationType type;
  late String contactPhone;
  late bool setAsDefault;
  late String deliveryInstructions;

  LocationModel(
      {this.id,
      this.uniqueId,
      this.locationLabel = '',
      this.favourite = 0,
      this.street = "",
      this.zip,
      this.city = "",
      this.state = "",
      this.country = "",
      this.utcModifier = "Europe/Tallinn",
      this.lat = 0,
      this.lng = 0,
      this.type = LocationType.home,
      this.contactPhone = '',
      this.deliveryInstructions = '',
      this.setAsDefault = false});

  LocationModel.fromJson(Map<String, dynamic> json) {
    id = json['locationId'] ?? 0;
    uniqueId = json['uniqueId'] ?? '';
    locationLabel = json['locationLabel'] ?? '';
    favourite = json['favourite'] ?? 0;
    street = json['street'] ?? '';
    zip = json['zip'] ?? '';
    city = json['city'] ?? '';
    state = json['state'] ?? '';
    country = json['country'] ?? '';
    utcModifier = json['utcModifier'] ?? '';
    lat = json['lat'] ?? 0;
    lng = json['lng'] ?? 0;
    type = LocationType.values[json['type'] ?? 0];
    contactPhone = json['contactPhone'] ?? '';
    deliveryInstructions = json['deliveryInstructions'] ?? '';
    setAsDefault = json['setAsDefault'] == 1;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['locationId'] = this.id;
    data['uniqueId'] = this.uniqueId;
    data['locationLabel'] = this.locationLabel;
    data['favourite'] = this.favourite;
    data['street'] = this.street;
    data['zip'] = this.zip;
    data['city'] = this.city;
    data['state'] = this.state;
    data['country'] = this.country;
    data['utcModifier'] = this.utcModifier;
    data['lat'] = this.lat;
    data['lng'] = this.lng;
    data['type'] = this.type.index;
    data['setAsDefault'] = this.setAsDefault ? 1 : 0;
    data['contactPhone'] = this.contactPhone;
    data['deliveryInstructions'] = this.deliveryInstructions;
    return data;
  }

  @override
  String toString() {
    return street + "\n" + city + "\n" + state + "\n" + country;
  }

  String toAddressString() {
    return street + ", " + city + ", " + state + ", " + country;
  }

  String toAddressString2() {
    return street +
        "\n" +
        city +
        '${zip != null && zip!.isNotEmpty ? ' $zip' : ''}' +
        ", " +
        "\n" +
        state +
        ", " +
        country;
  }

  String toAddress2String() {
    if (zip!.isNotEmpty)
      return '$street\n$zip $city\n$country';
    else
      return '$street\n$city\n$country';
  }

  String toAddress3String() {
    return '$country\n$zip $city\n$street';
  }
}
