import 'dart:developer';

import 'package:dio/dio.dart' as dio;

class NetworkResponse<T> {
  static String disconnectError = 'disconnectError';
  static String unknownError = 'unknownError';

  int? code;
  T? data;
  String? msg;

  bool get isSuccess => code == 200 && data != null;

  bool get isError => code != 200;

  NetworkResponse({this.data, this.code, this.msg});

  factory NetworkResponse.fromResponse(dio.Response response,
      {converter, value, String? prefix}) {
    try {
      return NetworkResponse._fromJson(response.data,
          converter: converter, prefix: prefix, value: value)
        ..code = response.statusCode;
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  NetworkResponse._fromJson(dynamic json, {converter, value, String? prefix}) {
    if (value != null) {
      data = value;
    } else if (prefix != null) {
      if (prefix.trim().isEmpty) {
        data = converter != null && json != null ? converter(json) : json;
      } else {
        data = converter != null && json[prefix] != null
            ? converter(json[prefix])
            : json[prefix];
      }
    } else {
      data = converter != null && json["values"] != null
          ? converter(json["values"])
          : json["values"];
    }
  }

  Map<String, dynamic> toJson() {
    var map = <String, dynamic>{};
    map["code"] = code;
    map["data"] = data;
    map["error"] = msg;
    return map;
  }

  NetworkResponse.withErrorRequest(dio.DioError error) {
    log("NetworkResponse.withErrorRequest: $error");
    try {
      data = null;
      dio.Response? response = error.response;
      code = response?.statusCode ?? 500;
      if (response?.data?['error'] != null) {
        this.msg = response?.data?['error'];
      }
    } catch (e) {
      log("NetworkResponse.withErrorRequest2: $e");
    }
  }

  NetworkResponse.withErrorConvert(error) {
    log("NetworkResponse.withErrorConvert: $error");
    data = null;
    this.msg = unknownError;
  }

  NetworkResponse.withDisconnect() {
    log("NetworkResponse.withDisconnect");
    data = null;
    this.msg = disconnectError;
  }
}
