import 'package:_private_core/_private_core.dart';
import '../resources.dart';

class PublicEventRepository {
  PublicEventRepository._();

  static PublicEventRepository? _instance;

  factory PublicEventRepository([AppApi? api]) {
    _instance ??= PublicEventRepository._();
    _instance!._api = api ?? AppApiImp();
    return _instance!;
  }

  late AppApi _api;

  Future<List<PublishEvent>> getAllPublicEventsFromSearch(
      {search, lat, lng, maxDistance, languageCode}) async {
    Map<String, dynamic> params = {};
    if (search != null) params.addAll({'search': search});
    if (languageCode != null) params.addAll({'languageCode': languageCode});
    if (lat != null) params.addAll({'lat': lat});
    if (lng != null) params.addAll({'lng': lng});
    if (maxDistance != null) params.addAll({'maxDistance': maxDistance});
    NetworkResponse response = await _api.getAllPublicEventsFromSearch(params);
    return response.data ?? [];
  }

  Future<List<PublishEvent>> getSuggestionEventsFromUser(
      {lat, lng, utcModifier, languageCode}) async {
    Map<String, dynamic> params = {};
    if (languageCode != null) params.addAll({'languageCode': languageCode});
    if (lat != null) params.addAll({'lat': lat});
    if (lng != null) params.addAll({'lng': lng});
    if (utcModifier != null) params.addAll({'utcModifier': utcModifier});
    NetworkResponse response = await _api.getSuggestionEventsFromUser(params);
    return response.data ?? [];
  }

  Future<List<PublishEventCategory>> getPublicEventsCategories(
      {languageCode}) async {
    NetworkResponse response = await _api
        .getPublicEventsCategories(languageCode ?? appPrefs.languageCode);
    return response.data ?? [];
  }

  Future<List<PublishEventCategory>> getFavoritePublicEventsCategoriesFromUser(
      {languageCode}) async {
    NetworkResponse response =
        await _api.getFavoritePublicEventsCategoriesFromUser(languageCode);
    return response.data ?? [];
  }

  Future<List<PublishEvent>> getAllPublicEventsAroundMe(
      {lat, lng, maxDistance, languageCode, List<int>? cateIds}) async {
    Map<String, dynamic> params = {};
    if (cateIds != null && cateIds.isNotEmpty) {
      String _ = '';
      cateIds.forEach((e) {
        _ += '$e,';
      });
      _ = _.substring(0, _.length - 1);
      params.addAll({'catId': _});
    }
    if (languageCode != null) {
      params.addAll({'languageCode': languageCode ?? appPrefs.languageCode});
    }
    if (lat != null) params.addAll({'lat': lat});
    if (lng != null) params.addAll({'lng': lng});
    if (maxDistance != null) params.addAll({'maxDistance': maxDistance});
    NetworkResponse response = await _api.getAllPublicEventsAroundMe(params);
    return response.data ?? [];
  }

  Future<List<PublishEvent>> getPublicEventsListFromUser(
      {lat, lng, maxDistance, languageCode}) async {
    Map<String, dynamic> params = {};
    if (languageCode != null) params.addAll({'languageCode': languageCode});
    if (lat != null) params.addAll({'lat': lat});
    if (lng != null) params.addAll({'lng': lng});
    if (maxDistance != null) params.addAll({'maxDistance': maxDistance});
    NetworkResponse response = await _api.getPublicEventsListFromUser(params);
    return response.data ?? [];
  }

  Future<List<PublishEvent>> getLikedPublicEventsFromUser() async {
    NetworkResponse response = await _api.getLikedPublicEventsFromUser();
    return response.data ?? [];
  }

  Future<bool> addUserLikeToPublicEvent(publicEventId) async {
    NetworkResponse response =
        await _api.addUserLikeToPublicEvent(publicEventId);
    return response.data ?? false;
  }

  Future<bool> setFavoriteCatForUser(catId) async {
    NetworkResponse response = await _api.setFavoriteCatForUser(catId);
    return response.data ?? false;
  }

  Future<bool> removeFavoriteCatForUser(catId) async {
    NetworkResponse response = await _api.removeFavoriteCatForUser(catId);
    return response.data ?? false;
  }

  Future<bool> addSeenSuggestionEventFromUser(
      publicEventId, utcModifier) async {
    NetworkResponse response =
        await _api.addSeenSuggestionEventFromUser(publicEventId, utcModifier);
    return response.data ?? false;
  }

  Future<bool> bookFreeTicketForPublicEvents(arckipelTicketId) async {
    NetworkResponse response =
        await _api.bookFreeTicketForPublicEvents(arckipelTicketId);
    return response.data ?? false;
  }

  Future<List<TicketInfoModel>> getTicketListFromPublicEvent(
      publicEventId) async {
    NetworkResponse response =
        await _api.getTicketListFromPublicEvent(publicEventId);
    return response.data ?? [];
  }
}
